# -*- coding: utf-8 -*-
from setuphelpers import *


def install():
    if Version(windows_version()) >= Version(WindowsVersions.Windows8):    
        print("Disabling: Hiberboot (Fast Startup).")
        registry_set(HKEY_LOCAL_MACHINE, r"SYSTEM\CurrentControlSet\Control\Session Manager\Power", "HiberbootEnabled", 0)
    else:
        print("Hiberboot (Fast Startup) is only supported on Windows 8+.")

    # Forget duplicate packages
    for p in WAPT.installed():
        if "disable-hybrid-boot" in p.package:
            WAPT.forget_packages(p.package)
        if "disable-hybrid-shutdown" in p.package:
            WAPT.forget_packages(p.package)
        if "disable-fast-startup" in p.package:
            WAPT.forget_packages(p.package)



def uninstall():
    print("Reset to default: Hiberboot (Fast Startup).")
    registry_delete(HKEY_LOCAL_MACHINE, r"SYSTEM\CurrentControlSet\Control\Session Manager\Power", "HiberbootEnabled")


def audit():
    # Declaring local variables
    audit_status = "OK"
    if Version(windows_version()) >= Version(WindowsVersions.Windows8):    
        hibernation_state = registry_readstring(HKEY_LOCAL_MACHINE, r"SYSTEM\CurrentControlSet\Control\Session Manager\Power", "HiberbootEnabled")

        # Auditing package
        if hibernation_state == "1":
            print("Hiberboot (Fast Startup) is enabled.")
            audit_status = set_audit_status(audit_status, "ERROR")
        elif hibernation_state == "0":
            print("Hiberboot (Fast Startup) is disabled.")
            # audit_status = set_audit_status(audit_status, "OK")
    else:
        print("Hiberboot (Fast Startup) is only supported on Windows 8+.")

    return audit_status


def set_audit_status(old_audit_status, new_audit_status):
    """Maintain higher criticality for audit status."""
    audit_level = {"OK": 0, "WARNING": 1, "ERROR": 2}

    old_status = old_audit_status.upper().strip()
    new_status = new_audit_status.upper().strip()

    if audit_level.get(new_status, -1) > audit_level.get(old_status, -1):
        return new_status
    else:
        return old_audit_status
